# Undetected

It aims to bypass common anti-bot and anti-detection mechanisms (such as Cloudflare) by patching the Selenium WebDriver and applying advanced stealth and fingerprinting techniques to better mimic real user behavior.

**Note:** This project is a fork of [`undetected-chromedriver`](https://github.com/ultrafunkamsterdam/undetected-chromedriver).
